@@ -2,7 +2,7 @@ package ExtUtils::MM_Any;
 
 use strict;
 use vars qw($VERSION @ISA);
-$VERSION = '0.14';
+$VERSION = '6.38';
 
 use Carp;
 use File::Spec;
@@ -676,10 +676,6 @@ sub manifypods_target {
         $dependencies .= " \\\n\t$name";
     }
 
-    foreach my $name (keys %{$self->{MAN3PODS}}) {
-        $dependencies .= " \\\n\t$name"
-    }
-
     my $manify = <<END;
 manifypods : pure_all $dependencies
 END
@@ -725,12 +721,17 @@ MAKE_FRAG
         $prereq_pm .= sprintf "\n    %-30s %s", "$mod:", $ver;
     }
 
+    my $author_value = defined $self->{AUTHOR}
+        ? "\n    - $self->{AUTHOR}"
+        : undef;
+
     # Use a list to preserve order.
     my @meta_to_mm = (
         name         => $self->{DISTNAME},
         version      => $self->{VERSION},
         abstract     => $self->{ABSTRACT},
         license      => $self->{LICENSE},
+        author       => $author_value,
         generated_by => 
                 "ExtUtils::MakeMaker version $ExtUtils::MakeMaker::VERSION",
         distribution_type => $self->{PM} ? 'module' : 'script',
@@ -749,13 +750,8 @@ MAKE_FRAG
     $meta .= <<"YAML";
 requires:     $prereq_pm
 meta-spec:
-    url:     http://module-build.sourceforge.net/META-spec-v1.2.html
-    version: 1.2
-YAML
-
-    $meta .= <<"YAML" if defined $self->{AUTHOR};
-author:
-    - $self->{AUTHOR}
+    url:     http://module-build.sourceforge.net/META-spec-v1.3.html
+    version: 1.3
 YAML
 
     $meta .= $self->{EXTRA_META} if $self->{EXTRA_META};
